searchData={"items":[{"type":"module","title":"ExAttr","doc":"Simple utility library that performs native [xattr](https://man7.org/linux/man-pages/man7/xattr.7.html)\noperations using rustler and the [`xattr`](https://docs.rs/xattr/latest/xattr/index.html)\ncrate created by [Steven Allen](https://github.com/Stebalien)","ref":"ExAttr.html"},{"type":"module","title":"Rational - ExAttr","doc":"I was disappointed to see that there was no native interface within Elixir or Erlang's\nstandard libraries for managing extended attributes. While this can technically be worked\naround by simply wrapping the `setfattr` and `getfattr` commands, I wasn't happy with the\nperformance of this approach.\n\nAdditionally, while there are similar libraries that handle xattr operations for Elixir,\nI'm picky about how I handle serialization and was looking for something less opinionated\nand \"dumb\" that I could easily wrap my application specific logic around.\n\nSince I couldn't find anything that fit this criteria I figured I'd just do it myself, and so here we are!","ref":"ExAttr.html#module-rational"},{"type":"module","title":"Namespacing Advise - ExAttr","doc":"If you want to add some custom-application-specific xattrs to a file, it's generally a good idea to do this all\nunder a common namespace specific to your application. Since POSIX extended attributes already has some built-in\nnamespacing that differentiates between `trusted`, `system`, `user`, etc, it is highly likely you will need to make\nyour namespace a child of the `user` namespace (ex: `\"user. \"`) unless you are doing SELinux stuff.\n\nThis is most easily abstracted away by simply wrapping the functions of this library to auto handle all that for you.\nHere is an example of what I mean:\n```elixir\ndefmodule MyApp.XAttr do\n  @namespace \"user.my_apps_namespace\"\n\n  def set(path, name, value) do\n    name = \"#{@namespace}.#{name}\"\n    ExAttr.set(path, name, value)\n  end\n\n  def get(path, name) do\n    name = \"#{@namespace}.#{name}\"\n    ExAttr.get(path, name)\n  end\n\n  def list(path) do\n    case ExAttr.list(path) do\n      {:ok, list} ->\n        list\n        |> Enum.filter(&match?(\"#{@namespace}.\" <> _, &1))\n        |> Enum.map(fn \"#{@namespace}.\" <> name -> name end)\n        |> then(fn list ->\n          {:ok, list}\n        end)\n\n      {:error, reason} ->\n        {:error, reason}\n    end\n  end\n\n  # And so on...\nend\n```","ref":"ExAttr.html#module-namespacing-advise"},{"type":"function","title":"ExAttr.dump/1","doc":"Dumps map of extended attributes for the specified file.\n\n> #### Note {: .info}\n> This may not list all attributes. Speficially, it definitely won’t list any trusted attributes unless you are root and it may not list system attributes.","ref":"ExAttr.html#dump/1"},{"type":"function","title":"Examples - ExAttr.dump/1","doc":"```elixir\niex> :ok = ExAttr.set(\"test.txt\", \"user.foo\", \"bar\")\niex> :ok = ExAttr.set(\"test.txt\", \"user.bar\", \"foo\")\niex> :ok = ExAttr.set(\"test.txt\", \"user.test\", \"example\")\niex> ExAttr.dump(\"test.txt\")\n{:ok, %{\"user.bar\" => \"foo\", \"user.foo\" => \"bar\", \"user.test\" => \"example\"}}\n```","ref":"ExAttr.html#dump/1-examples"},{"type":"function","title":"ExAttr.dump!/1","doc":"Dumps map of extended attributes for the specified file, raises on error.\n\n> #### Note {: .info}\n> This may not list all attributes. Speficially, it definitely won’t list any trusted attributes unless you are root and it may not list system attributes.","ref":"ExAttr.html#dump!/1"},{"type":"function","title":"ExAttr.get/2","doc":"Get an extended attribute for the specified file.","ref":"ExAttr.html#get/2"},{"type":"function","title":"Examples - ExAttr.get/2","doc":"```elixir\niex> ExAttr.get(\"test.txt\", \"user.foo\")\n{:ok, nil}\niex> ExAttr.set(\"test.txt\", \"user.foo\", \"123\")\n:ok\niex> ExAttr.get(\"test.txt\", \"user.foo\")\n{:ok, \"123\"}\n```","ref":"ExAttr.html#get/2-examples"},{"type":"function","title":"ExAttr.get!/2","doc":"Get an extended attribute for the specified file, raises on error","ref":"ExAttr.html#get!/2"},{"type":"function","title":"ExAttr.list/1","doc":"List extended attributes attached to the specified file.\n\n> #### Note {: .info}\n> This may not list all attributes. Speficially, it definitely won’t list any trusted attributes unless you are root and it may not list system attributes.","ref":"ExAttr.html#list/1"},{"type":"function","title":"Examples - ExAttr.list/1","doc":"```elixir\niex> :ok = ExAttr.set(\"test.txt\", \"user.foo\", \"bar\")\niex> :ok = ExAttr.set(\"test.txt\", \"user.bar\", \"foo\")\niex> :ok = ExAttr.set(\"test.txt\", \"user.test\", \"example\")\niex> ExAttr.list(\"test.txt\")\n{:ok, [\"user.test\", \"user.bar\", \"user.foo\"]}\n```","ref":"ExAttr.html#list/1-examples"},{"type":"function","title":"ExAttr.list!/1","doc":"List extended attributes attached to the specified file, raises on error.\n\n> #### Note {: .info}\n> This may not list all attributes. Speficially, it definitely won’t list any trusted attributes unless you are root and it may not list system attributes.","ref":"ExAttr.html#list!/1"},{"type":"function","title":"ExAttr.remove/2","doc":"Remove an extended attribute from the specified file.","ref":"ExAttr.html#remove/2"},{"type":"function","title":"Examples - ExAttr.remove/2","doc":"```elixir\niex> ExAttr.set(\"test.txt\", \"user.foo\", \"123\")\n:ok\niex> ExAttr.get(\"test.txt\", \"user.foo\")\n{:ok, \"123\"}\niex> ExAttr.remove(\"test.txt\", \"user.foo\")\n:ok\niex> ExAttr.get(\"test.txt\", \"user.foo\")\n{:ok, nil}\niex> ExAttr.remove(\"test.txt\", \"user.foo\")\n{:error, \"No data available (os error 61)\"}\n```","ref":"ExAttr.html#remove/2-examples"},{"type":"function","title":"ExAttr.remove!/2","doc":"Remove an extended attribute from the specified file, raises on error.","ref":"ExAttr.html#remove!/2"},{"type":"function","title":"ExAttr.set/3","doc":"Set an extended attribute on the specified file. Passing a `nil` value will remove the attribute.","ref":"ExAttr.html#set/3"},{"type":"function","title":"Examples - ExAttr.set/3","doc":"```elixir\niex> ExAttr.set(\"test.txt\", \"user.foo\", \"123\")\n:ok\niex> ExAttr.get(\"test.txt\", \"user.foo\")\n{:ok, \"123\"}\niex> ExAttr.set(\"test.txt\", \"user.foo\", nil)\n:ok\niex> ExAttr.get(\"test.txt\", \"user.foo\")\n{:ok, nil}\n```","ref":"ExAttr.html#set/3-examples"},{"type":"function","title":"ExAttr.set!/3","doc":"Set an extended attribute on the specified file. Passing a `nil` value will remove the attribute, raises on error.","ref":"ExAttr.html#set!/3"},{"type":"function","title":"ExAttr.supported_platform/0","doc":"Forwards the result of the `xattr:SUPPORTED_PLATFORM` function from\nthe `xattr` crate this library wraps.\n\nReturns true if platform is supported.","ref":"ExAttr.html#supported_platform/0"},{"type":"type","title":"ExAttr.name/0","doc":"","ref":"ExAttr.html#t:name/0"},{"type":"type","title":"ExAttr.result/0","doc":"","ref":"ExAttr.html#t:result/0"},{"type":"type","title":"ExAttr.result/1","doc":"","ref":"ExAttr.html#t:result/1"},{"type":"type","title":"ExAttr.value/0","doc":"","ref":"ExAttr.html#t:value/0"},{"type":"module","title":"ExAttr.Nif","doc":"Wraps the [`xattr`](https://docs.rs/xattr/latest/xattr/index.html) crate using rustler","ref":"ExAttr.Nif.html"},{"type":"function","title":"ExAttr.Nif.get_xattr/2","doc":"","ref":"ExAttr.Nif.html#get_xattr/2"},{"type":"function","title":"ExAttr.Nif.list_xattr/1","doc":"","ref":"ExAttr.Nif.html#list_xattr/1"},{"type":"function","title":"ExAttr.Nif.remove_xattr/2","doc":"","ref":"ExAttr.Nif.html#remove_xattr/2"},{"type":"function","title":"ExAttr.Nif.set_xattr/3","doc":"","ref":"ExAttr.Nif.html#set_xattr/3"},{"type":"function","title":"ExAttr.Nif.supported_platform/0","doc":"","ref":"ExAttr.Nif.html#supported_platform/0"},{"type":"exception","title":"ExAttr.Error","doc":"An exception that is raised when a ExAttr operation fails.\n\nThe following fields of this exception are public and can be accessed freely:\n\n  * `:path` (`t:Path.t/0`) - the path of the file that caused the error\n  * `:reason` (`t:String.t/0`) - the reason for the error","ref":"ExAttr.Error.html"},{"type":"extras","title":"ExAttr","doc":"# ExAttr\n![Hex.pm Version](https://img.shields.io/hexpm/v/ex_attr) [![Documentation](https://img.shields.io/badge/documentation-gray)](https://hexdocs.pm/ex_attr)\n\nSimple utility library that performs native [extended attribute](https://man7.org/linux/man-pages/man7/xattr.7.html)\noperations using rustler and the [`xattr`](https://github.com/Stebalien/xattr)\ncrate created by [Steven Allen](https://github.com/Stebalien).\n\nIn theory this should support every platform the [`xattr`](https://github.com/Stebalien/xattr) crate supports, which includes: Android, Linux, MacOS, FreeBSD, and NetBSD. However I've only tested this on Linux.","ref":"readme.html"},{"type":"extras","title":"Rational - ExAttr","doc":"I was disappointed to see that there was no native interface within Elixir or Erlang's\nstandard libraries for managing extended attributes. While this can technically be worked\naround by simply wrapping the `setfattr` and `getfattr` commands, I wasn't happy with the\nperformance of this approach.\n\nAdditionally, while there are similar libraries that handle xattr operations for Elixir,\nI'm picky about how I handle serialization and was looking for something less opinionated\nand \"dumb\" that I could easily wrap my application specific logic around.\n\nSince I couldn't find anything that fit this criteria I figured I'd just do it myself, and so here we are!","ref":"readme.html#rational"},{"type":"extras","title":"Installation - ExAttr","doc":"The package can be installed by adding `ex_attr` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ex_attr, \"~> 1.0.1\"}\n  ]\nend\n```","ref":"readme.html#installation"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,48]}}